/*
 * Copyright (C) 2012 Ian G. Clifton
 * Used in The Essentials of Android Application Development LiveLessons
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.iangclifton.android;

import android.app.Activity;
import android.content.Intent;
import android.os.Bundle;
import android.support.v4.app.Fragment;
import android.view.LayoutInflater;
import android.view.View;
import android.view.View.OnClickListener;
import android.view.ViewGroup;
import android.widget.LinearLayout;
import android.widget.Toast;

import com.iangclifton.android.io.ReadInternalFileString;
import com.iangclifton.android.io.SaveInternalFile;
import com.iangclifton.android.location.LocationActivity;
import com.iangclifton.android.location.MapViewActivity;
import com.iangclifton.android.media.AudioActivity;
import com.iangclifton.android.media.SystemCameraActivity;
import com.iangclifton.android.media.VideoActivity;
import com.iangclifton.android.opengl.OpenGLActivity;
import com.iangclifton.android.phone.PhoneActivity;
import com.iangclifton.android.preferences.OurPreferenceActivity;
import com.iangclifton.android.receivers.BatteryMonitorActivity;
import com.iangclifton.android.renderscript.RenderScriptActivity;
import com.iangclifton.android.sensors.SensorsActivity;
import com.iangclifton.android.services.WeatherService;
import com.iangclifton.android.view.CustomLayoutActivity;
import com.iangclifton.android.webaccess.CustomHttpHandlingActivity;
import com.iangclifton.android.webaccess.WebViewExample;

/**
 * Fragment that displays the main menu to direct the user to other Activities.
 * 
 * @author Ian G. Clifton
 */
public class MainMenuFragment extends Fragment implements OnClickListener {

	@Override
	public View onCreateView(LayoutInflater inflater, ViewGroup container,
			Bundle savedInstanceState) {
		View v = inflater.inflate(R.layout.mainmenu, container, false);
		
		// Get the ViewGroup that contains all the buttons and loop through
		// its children, setting this as the OnClickListener for each one
		LinearLayout ll = (LinearLayout) v.findViewById(R.id.button_container);
		int childCount = ll.getChildCount();
		for (int i = 0; i < childCount; i++) {
			ll.getChildAt(i).setOnClickListener(this);
		}
		return v;
	}

	@Override
	public void onClick(View view) {
		Intent i = null;
		switch (view.getId()) {
			case R.id.custom_http_button:
				i = new Intent(getActivity(), CustomHttpHandlingActivity.class);
				break;
			case R.id.webview_button:
				i = new Intent(getActivity(), WebViewExample.class);
				break;
			case R.id.weather_service_button:
				Intent serviceIntent = new Intent(getActivity(), WeatherService.class);
				getActivity().startService(serviceIntent);
				break;
			case R.id.battery_monitor_button:
				i = new Intent(getActivity(), BatteryMonitorActivity.class);
				break;
			case R.id.preferences_button:
				i = new Intent(getActivity(), OurPreferenceActivity.class);
				break;
			case R.id.save_internal_button:
				new SaveInternalFile("testfile", "These are the bytes you're looking for".getBytes()).execute(getActivity());
				break;
			case R.id.read_internal_button:
				new ReadInternalFileString("testfile") {
					@Override
					protected void onPostExecute(String result) {
						Activity activity = getActivity();
						if (activity != null) {
							Toast.makeText(activity, "Read file:\n" + result, Toast.LENGTH_LONG).show();
						}
					}
				}.execute(getActivity());
				break;
			case R.id.telephony_button:
				i = new Intent(getActivity(), PhoneActivity.class);
				break;
			case R.id.sensor_button:
				i = new Intent(getActivity(), SensorsActivity.class);
				break;
			case R.id.audio_button:
				i = new Intent(getActivity(), AudioActivity.class);
				break;
			case R.id.video_button:
				i = new Intent(getActivity(), VideoActivity.class);
				break;
			case R.id.system_camera_button:
				i = new Intent(getActivity(), SystemCameraActivity.class);
				break;
			case R.id.location_button:
				i = new Intent(getActivity(), LocationActivity.class);
				break;
			case R.id.mapview_button:
				i = new Intent(getActivity(), MapViewActivity.class);
				break;
			case R.id.custom_layout_button:
				i = new Intent(getActivity(), CustomLayoutActivity.class);
				break;
			case R.id.opengl_button:
				i = new Intent(getActivity(), OpenGLActivity.class);
				break;
			case R.id.renderscript_button:
				i = new Intent(getActivity(), RenderScriptActivity.class);
				break;
		}
		if (i != null) {
			startActivity(i);
		}
	}

}
