/*
 * Copyright (C) 2012 Ian G. Clifton
 * Used in The Essentials of Android Application Development LiveLessons
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.iangclifton.android;

import android.app.Activity;
import android.os.AsyncTask;
import android.os.Bundle;
import android.text.format.DateUtils;
import android.widget.TextView;

public class NextActivity extends Activity {

	private TextView mResultTextView;

	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);

		setContentView(R.layout.next);
		mResultTextView = (TextView) findViewById(R.id.ResultTextView);
		new LongRunningTask().execute(new String[] {
				"This is a string!", "And here is another" });
	}

	private class LongRunningTask extends AsyncTask<String, String, String> {

		@Override
		protected String doInBackground(String... params) {

			StringBuilder sb = new StringBuilder();
			int i = 0;
			for (String string : params) {
				if (isCancelled()) {
					return sb.toString();
				}
				StringBuilder tmp = new StringBuilder(string);
				sb.append(tmp.reverse()).append('\n');

				final long time = System.currentTimeMillis();
				while (time + DateUtils.SECOND_IN_MILLIS > System
						.currentTimeMillis()) {
					// Do nothing
				}

				// Track progress
				float progress = (float) i / (float) params.length * 100;
				progress = (float) Math.floor(progress);
				publishProgress("Progress: " + progress + "%");

				i++;
			}

			return sb.toString();
		}
		
		@Override
		protected void onPostExecute(String result) {
			super.onPostExecute(result);
			mResultTextView.setText(result);
		}

		@Override
		protected void onProgressUpdate(String... values) {
			mResultTextView.setText(values[0]);
		}

	}
}
