/*
 * Copyright (C) 2012 Ian G. Clifton
 * Used in The Essentials of Android Application Development LiveLessons
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.iangclifton.android.io;

import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;

import android.content.Context;
import android.os.AsyncTask;

/**
 * An AsyncTask which reads a String from an internal file.
 * 
 * @author Ian G. Clifton
 */
public class ReadInternalFileString extends AsyncTask<Context, Void, String> {
	
	private final String mFilename;
	
	/**
	 * Constructs a new ReadInternalFileString with the given filename
	 * 
	 * @param filename String name of the file to load in the background
	 */
	public ReadInternalFileString(String filename) {
		mFilename = filename;
	}

	@Override
	protected String doInBackground(Context... params) {
		Context context = params[0];
		params = null;
		FileInputStream fis = null;
		
		try {
			fis = context.openFileInput(mFilename);
			context = null;
			StringBuilder sb = new StringBuilder();
			byte[] buffer = new byte[1024];
			while (fis.read(buffer) != -1) {
				sb.append(new String(buffer));
			}
			return sb.toString().trim();
		} catch (FileNotFoundException e) {
			// TODO You should handle Exceptions appropriately for your app
			e.printStackTrace();
		} catch (IOException e) {
			// TODO You should handle Exceptions appropriately for your app
			e.printStackTrace();
		} finally {
			if (fis != null) {
				try {
	                fis.close();
                } catch (IOException e) {
        			// TODO You should handle Exceptions appropriately for your app
	                e.printStackTrace();
                }
			}
		}
		return null;
	}
}
