/*
 * Copyright (C) 2012 Ian G. Clifton
 * Used in The Essentials of Android Application Development LiveLessons
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.iangclifton.android.io;

import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;

import android.content.Context;
import android.os.AsyncTask;

/**
 * AsyncTask to save bytes to an internal file.
 * 
 * @author Ian G. Clifton
 */
public class SaveInternalFile extends AsyncTask<Context, Void, Boolean> {
	private final String mFilename;
	private final byte[] mBytes;
	
	/**
	 * Constructs a new SaveInternalFile with the passed filename and bytes array
	 * @param filename String name of the file
	 * @param bytes array of bytes to store in the file
	 */
	public SaveInternalFile(String filename, byte[] bytes) {
		mFilename = filename;
		mBytes = bytes;
	}

	@Override
	protected Boolean doInBackground(Context... params) {
		FileOutputStream fos = null;
		Context context = params[0];
		params = null;
		
		try {
			fos = context.openFileOutput(mFilename, Context.MODE_PRIVATE);
			context = null;
			fos.write(mBytes);
		} catch (FileNotFoundException e) {
			// TODO You should handle Exceptions appropriately for your app
			e.printStackTrace();
		} catch (IOException e) {
			// TODO You should handle Exceptions appropriately for your app
			e.printStackTrace();
		} finally {
			if (fos != null) {
				try {
					fos.close();
					return Boolean.valueOf(true);
				} catch (IOException e) {
					// TODO You should handle Exceptions appropriately for your app
					e.printStackTrace();
				}
			}
		}
		
		return Boolean.valueOf(false);
	}

}
