/*
 * Copyright (C) 2012 Ian G. Clifton
 * Used in The Essentials of Android Application Development LiveLessons
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.iangclifton.android.location;

import android.os.Bundle;

import com.google.android.maps.MapActivity;
import com.google.android.maps.MapController;
import com.google.android.maps.MapView;
import com.google.android.maps.MyLocationOverlay;
import com.iangclifton.android.R;

/**
 * MapActivity that demonstrates basic usage of a MapView.
 * 
 * Note that your Activity must extend MapActivity if it contains a MapView.
 * That means you cannot (easily) use Fragments.  There are various solutions
 * discussed here: http://code.google.com/p/android/issues/detail?id=15347
 * 
 * @author Ian G. Clifton
 */
public class MapViewActivity extends MapActivity {
	
	private MapController mMapController;
	private MyLocationOverlay mMyLocationOverlay;

	@Override
	protected boolean isRouteDisplayed() {
		return false;
	}

	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		
		setContentView(R.layout.mapview);
		MapView mapView = (MapView) findViewById(R.id.mapview);
		mMapController = mapView.getController();
		mMyLocationOverlay = new MyLocationOverlay(this, mapView);
		mMyLocationOverlay.runOnFirstFix(new Runnable() {
			@Override
			public void run() {
				mMapController.animateTo(mMyLocationOverlay.getMyLocation());
			}
		});
		mMyLocationOverlay.enableMyLocation();
		mMapController.setZoom(15);
	}

	
}
