/*
 * Copyright (C) 2012 Ian G. Clifton
 * Used in The Essentials of Android Application Development LiveLessons
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.iangclifton.android.media;

import android.media.MediaPlayer;
import android.media.MediaPlayer.OnCompletionListener;
import android.os.Bundle;
import android.support.v4.app.FragmentActivity;
import android.view.View;
import android.view.View.OnClickListener;

import com.iangclifton.android.R;

/**
 * An Activity that demonstrates playing audio with a MediaPlayer.
 * 
 * @author Ian G. Clifton
 */
public class AudioActivity extends FragmentActivity implements OnClickListener {

	private View mButton = null;
	private MediaPlayer mMediaPlayer = null;
	
	@Override
	public void onClick(View v) {
		v.setEnabled(false);
		// The MediaPlayer is lazy loaded on the first button press
		if (mMediaPlayer == null) {
			mMediaPlayer = MediaPlayer.create(this, R.raw.testaudio);
			mMediaPlayer.setOnCompletionListener(new OnCompletionListener() {

				@Override
				public void onCompletion(MediaPlayer mp) {
					mButton.setEnabled(true);
				}
				
			});
		}
		mMediaPlayer.start();
	}
	
	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		
		setContentView(R.layout.audio);
		
		mButton = findViewById(R.id.audio_button);
		mButton.setOnClickListener(this);
	}

	@Override
	protected void onPause() {
		super.onPause();
		
		// If the MediaPlayer has been instantiated, we stop it and release
		// the resources it uses.
		if (mMediaPlayer != null) {
			mMediaPlayer.stop();
			mMediaPlayer.release();
			mMediaPlayer = null;
		}
	}

	
}
