/*
 * Copyright (C) 2012 Ian G. Clifton
 * Used in The Essentials of Android Application Development LiveLessons
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.iangclifton.android.media;

import java.io.File;

import android.content.Intent;
import android.graphics.Bitmap;
import android.net.Uri;
import android.os.Bundle;
import android.os.Environment;
import android.provider.MediaStore;
import android.support.v4.app.FragmentActivity;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.ImageView;

import com.iangclifton.android.R;

/**
 * An Activity which demonstrates creating an Intent to take a photo.
 * 
 * Completely handling taking photos yourself is a deceptively large amount of
 * work (assuming you want to do it right), so you should generally allow the
 * user to choose his/her own app to use.  This can also give the benefit of
 * allowing apps that have special effects.
 * 
 * @author Ian G. Clifton
 */
public class SystemCameraActivity extends FragmentActivity implements OnClickListener {

	/**
	 * Request code for capturing a photo
	 */
	private static final int CAPTURE_PHOTO = 1;
	
	private Uri mOutputFileUri = null;
	
	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		
		setContentView(R.layout.system_camera);
		findViewById(R.id.camera_button).setOnClickListener(this);
	}

	@Override
	public void onClick(View view) {
		Intent intent = new Intent(MediaStore.ACTION_IMAGE_CAPTURE);
		File file = new File(Environment.getExternalStorageDirectory(), "test-" + System.currentTimeMillis() + ".jpg");
		mOutputFileUri = Uri.fromFile(file);
		intent.putExtra(MediaStore.EXTRA_OUTPUT, mOutputFileUri);
		startActivityForResult(intent, CAPTURE_PHOTO);
	}

	@Override
	protected void onActivityResult(int requestCode, int resultCode, Intent intent) {
		
		if (requestCode == CAPTURE_PHOTO) {
			if (intent != null && intent.hasExtra("data")) {
				Bitmap thumbnail = intent.getParcelableExtra("data");
				ImageView imageView = (ImageView) findViewById(R.id.thumbnail);
				imageView.setImageBitmap(thumbnail);
			}
		}
	}

	
}
