/*
 * Copyright (C) 2012 Ian G. Clifton
 * Used in The Essentials of Android Application Development LiveLessons
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.iangclifton.android.opengl;

import java.nio.ByteBuffer;
import java.nio.ByteOrder;
import java.nio.FloatBuffer;

import javax.microedition.khronos.opengles.GL10;

/**
 * Represents a simple pyramid with four sides and no base.
 * 
 * @author Ian G. Clifton
 */
public class SimplePyramid {
	
	private FloatBuffer mVertices;
	private FloatBuffer mColors;
	private ByteBuffer mIndices;
	
	public SimplePyramid() {
		float[] vertices = {
				 0f,  1f,  0f, // T
				-1f, -1f,  0f, // A
				 0f, -1f,  1f, // B
				 1f, -1f,  0f, // C
				 0f, -1f, -1f // D
		};
		
		float[] colors = {
			//R, G, B, A
				1f, 0f, 0f, 1f,
				0f, 1f, 0f, 1f,
				0f, 0f, 1f, 1f,
				1f, .3f, 0f, 1f,
				.5f, 0f, 1f, 1f
		};
		
		byte t = 0;
		byte a = 1;
		byte b = 2;
		byte c = 3;
		byte d = 4;
		
		// The commented out indices were the repeated ones used when we did the
		// drawing with GL_TRIANGLES
		byte[] indices = {
				t, a, b,
				/*t, b,*/ c,
				/*t, c,*/ d,
				/*t, d,*/ a
		};
		
		// First we allocate four bytes for each vertex (since a float is four bytes)
		ByteBuffer vertexByteBuffer = ByteBuffer.allocateDirect(vertices.length * 4);
		// We re-order to the native order
		vertexByteBuffer.order(ByteOrder.nativeOrder());
		mVertices = vertexByteBuffer.asFloatBuffer();
		mVertices.put(vertices);
		mVertices.position(0);
		
		// We allocate four bytes for each color float
		ByteBuffer colorByteBuffer = ByteBuffer.allocateDirect(colors.length * 4);
		// Again re-ordering to the native order
		colorByteBuffer.order(ByteOrder.nativeOrder());
		mColors = colorByteBuffer.asFloatBuffer();
		mColors.put(colors);
		mColors.position(0);
		
		// Finally, we allocate the indices buffer
		// Since these are individual bytes, they don't need to be re-ordered
		mIndices = ByteBuffer.allocateDirect(indices.length);
		mIndices.put(indices);
		mIndices.position(0);
	}

	public void draw(GL10 gl) {
		// Define front face of polygons
		gl.glFrontFace(GL10.GL_CCW);
		
		gl.glVertexPointer(3, GL10.GL_FLOAT, 0, mVertices);
		gl.glColorPointer(4, GL10.GL_FLOAT, 0, mColors);
//		gl.glDrawElements(GL10.GL_TRIANGLES, 12, GL10.GL_UNSIGNED_BYTE, mIndices);
		gl.glDrawElements(GL10.GL_TRIANGLE_FAN, 6, GL10.GL_UNSIGNED_BYTE, mIndices);
	}
}
