/*
 * Copyright (C) 2012 Ian G. Clifton
 * Used in The Essentials of Android Application Development LiveLessons
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.iangclifton.android.phone;

import android.app.Activity;
import android.app.PendingIntent;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.net.Uri;
import android.os.Bundle;
import android.support.v4.app.FragmentActivity;
import android.telephony.SmsManager;
import android.telephony.TelephonyManager;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.TextView;

import com.iangclifton.android.R;

/**
 * An Activity which demonstrates sending calls and SMS messages from the app
 * directly and via an Intent.
 * 
 * @author Ian G. Clifton
 */
public class PhoneActivity extends FragmentActivity implements OnClickListener {
	
	private BroadcastReceiver mSentNotificationReceiver = new SentNotificationReceiver();
	
	@Override
	public void onClick(View v) {
		switch (v.getId()) {
			case R.id.send_app_call:
				Intent appCallIntent = new Intent(Intent.ACTION_CALL, Uri.parse("tel:5552368"));
				startActivity(appCallIntent);
				break;
			case R.id.send_system_call:
				Intent systemCallIntent = new Intent(Intent.ACTION_DIAL, Uri.parse("tel:5552368"));
				startActivity(systemCallIntent);
				break;
			case R.id.send_app_sms:
				String phoneNumber = "5552368";
				String messageBody = "Slimed from MY app!";
				SmsManager sm = SmsManager.getDefault();
				
				registerReceiver(mSentNotificationReceiver, new IntentFilter("my_special_action"));
				Intent sentIntent = new Intent("my_special_action");
				PendingIntent sentPendingIntent = PendingIntent.getBroadcast(this, 0, sentIntent, 0);
				
				sm.sendTextMessage(phoneNumber, null, messageBody, sentPendingIntent, null);
				TextView tv = (TextView) findViewById(R.id.phone_info);
				tv.setText("Possibly sent message");
				break;
			case R.id.send_system_sms:
				Intent systemSmsIntent = new Intent(Intent.ACTION_SENDTO, Uri.parse("sms:5552368"));
				systemSmsIntent.putExtra("sms_body", "I've been slimed!");
				startActivity(systemSmsIntent);
				break;
		}
	}
	
	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		
		setContentView(R.layout.phone);
		
		// Set all OnClickListeners as this
		findViewById(R.id.send_app_call).setOnClickListener(this);
		findViewById(R.id.send_system_call).setOnClickListener(this);
		findViewById(R.id.send_app_sms).setOnClickListener(this);
		findViewById(R.id.send_system_sms).setOnClickListener(this);
		
		// Simple demonstration of some of the phone info that is available
		// via the TelephonyManager
		TelephonyManager tm = (TelephonyManager) getSystemService(Context.TELEPHONY_SERVICE);
		StringBuilder sb = new StringBuilder();
		sb.append(tm.getLine1Number()).append('\n');
		sb.append(tm.getCellLocation()).append('\n');
		sb.append(tm.getNetworkOperatorName());
		TextView tv = (TextView) findViewById(R.id.phone_info);
		tv.setText(sb.toString());
	}
	
	

	@Override
	protected void onPause() {
		super.onPause();
		unregisterReceiver(mSentNotificationReceiver);
	}



	private class SentNotificationReceiver extends BroadcastReceiver {

		@Override
		public void onReceive(Context context, Intent intent) {
			TextView tv = (TextView) findViewById(R.id.phone_info);
			if (getResultCode() == Activity.RESULT_OK) {
				tv.setText("Message sent okay");
			} else {
				tv.setText("Message could not be sent");
			}
		}
		
	}
}
