/*
 * Copyright (C) 2012 Ian G. Clifton
 * Used in The Essentials of Android Application Development LiveLessons
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.iangclifton.android.preferences;

import android.content.Intent;
import android.content.SharedPreferences;
import android.content.SharedPreferences.OnSharedPreferenceChangeListener;
import android.os.Bundle;
import android.preference.PreferenceActivity;
import android.preference.PreferenceManager;

import com.iangclifton.android.R;
import com.iangclifton.android.services.WeatherService;

/**
 * A PreferenceActivity that loads preferences from XML.
 * 
 * Note that PreferenceFragments are the prefered solution as of API level 11.
 * 
 * @author Ian G. Clifton
 */
public class OurPreferenceActivity extends PreferenceActivity implements OnSharedPreferenceChangeListener {

	private String mShowCity;
	
	@SuppressWarnings("deprecation") // addPreferencesFromResource used to support older devices
    @Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		mShowCity = getString(R.string.show_city);
		addPreferencesFromResource(R.xml.our_preferences);
		PreferenceManager.getDefaultSharedPreferences(this).registerOnSharedPreferenceChangeListener(this);
	}

	@Override
	public void onSharedPreferenceChanged(SharedPreferences prefs, String key) {
		if (mShowCity.equals(key)) {
			Intent serviceIntent = new Intent(this, WeatherService.class);
			startService(serviceIntent);
		}
	}

}
