/*
 * Copyright (C) 2012 Ian G. Clifton
 * Used in The Essentials of Android Application Development LiveLessons
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.iangclifton.android.renderscript;

import android.annotation.TargetApi;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.os.Bundle;
import android.renderscript.Allocation;
import android.renderscript.RenderScript;
import android.support.v4.app.Fragment;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ImageView;

import com.iangclifton.android.R;

/**
 * Fragment for displaying the results of a RenderScript computation.
 * 
 * @author Ian G. Clifton
 */
@TargetApi(11)
public class ComputationFragment extends Fragment {
	private Bitmap mBitmapIn;
	private Bitmap mBitmapOut;
	private Allocation mAllocationIn;
	private Allocation mAllocationOut;
	private RenderScript mRS;
	private ScriptC_Computation mScript;
	private ImageView mImageViewIn;
	private ImageView mImageViewOut;
	

	@Override
	public void onActivityCreated(Bundle savedInstanceState) {
		super.onActivityCreated(savedInstanceState);
		
		mRS = RenderScript.create(getActivity());
		BitmapFactory.Options options = new BitmapFactory.Options();
		options.inPreferredConfig = Bitmap.Config.ARGB_8888;
		mBitmapIn = BitmapFactory.decodeResource(getResources(), R.drawable.sample_image, options);
		mBitmapOut = Bitmap.createBitmap(mBitmapIn.getWidth(), mBitmapIn.getHeight(), mBitmapIn.getConfig());
		mImageViewIn.setImageBitmap(mBitmapIn);
		mImageViewOut.setImageBitmap(mBitmapOut);
		
		triggerComputation();
	}

	@Override
	public View onCreateView(LayoutInflater inflater, ViewGroup container,
			Bundle savedInstanceState) {
		View v = inflater.inflate(R.layout.renderscript_compution, container, false);
		mImageViewIn = (ImageView) v.findViewById(R.id.input);
		mImageViewOut = (ImageView) v.findViewById(R.id.output);
		return v;
	}

	/**
	 * Begins the computation process via RenderScript
	 */
	private void triggerComputation() {
		mAllocationIn = Allocation.createFromBitmap(mRS, mBitmapIn, Allocation.MipmapControl.MIPMAP_NONE, Allocation.USAGE_SCRIPT);
		mAllocationOut = Allocation.createTyped(mRS, mAllocationIn.getType());
		mScript = new ScriptC_Computation(mRS, getResources(), R.raw.computation);
		
		mScript.set_gIn(mAllocationIn);
		mScript.set_gOut(mAllocationOut);
		mScript.set_gScript(mScript);
		mScript.invoke_convert();
		mAllocationOut.copyTo(mBitmapOut);
	}
}
