/*
 * Copyright (C) 2012 Ian G. Clifton
 * Used in The Essentials of Android Application Development LiveLessons
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
#pragma version(1)
#pragma rs java_package_name(com.iangclifton.android.renderscript);

#include "rs_graphics.rsh"

rs_allocation gImage;
rs_sampler gSampler;
rs_program_fragment gProgramFragment;
rs_program_store gProgramStore;
rs_program_vertex gProgramVertex;
float gRotation;

static const float3 gImageVertices[4] = {
    {-0.3, -0.3, -1.0},
    { 0.3, -0.3, -1.0},
    { 0.3,  0.3, -1.0},
    {-0.3,  0.3, -1.0}
};

static void drawBackground() {
    rsgClearColor(0.0f, 0.0f, 0.0f, 1.0f);
    
    rs_matrix4x4 projection, model;
    rsMatrixLoadOrtho(&projection, -1.0f, 1.0f, -1.0f, 1.0f, 0.0f, 1.0f);
    rsgProgramVertexLoadProjectionMatrix(&projection);
    
    rsMatrixLoadIdentity(&model);
    rsMatrixRotate(&model, gRotation, 0.0, 0.0, 1.0);
    rsgProgramVertexLoadModelMatrix(&model);
}

static void drawImage() {
    if (gImage.p != 0) {
        // Image ready to display
        rsgBindTexture(gProgramFragment, 0, gImage);
        
        rsgDrawQuad(
            gImageVertices[0].x, gImageVertices[0].y, gImageVertices[0].z,
            gImageVertices[1].x, gImageVertices[1].y, gImageVertices[1].z,
            gImageVertices[2].x, gImageVertices[2].y, gImageVertices[2].z,
            gImageVertices[3].x, gImageVertices[3].y, gImageVertices[3].z          
        );
    }
}

void init() {
    gRotation = 0.0f;
}

int root() {
    rsgBindProgramVertex(gProgramVertex);
    rsgBindProgramFragment(gProgramFragment);
    rsgBindProgramStore(gProgramStore);

    drawBackground();
    
    drawImage();
	return 16;
}