/*
 * Copyright (C) 2012 Ian G. Clifton
 * Used in The Essentials of Android Application Development LiveLessons
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.iangclifton.android.renderscript;

import android.annotation.TargetApi;
import android.content.Context;
import android.renderscript.RSSurfaceView;
import android.renderscript.RenderScriptGL;
import android.view.MotionEvent;

import com.iangclifton.android.R;

/**
 * Custom RSSurfaceView for displaying GraphicsRS.
 * 
 * @author Ian G. Clifton
 */
@TargetApi(11)
public class GraphicsRenderScriptView extends RSSurfaceView {
	private Context mContext;
	private RenderScriptGL mRS;
	private GraphicsRS mScript;

	public GraphicsRenderScriptView(Context context) {
		super(context);
		mContext = context;
		ensureRenderScript();
	}
	
	@Override
	public boolean onTouchEvent(MotionEvent event) {
		super.onTouchEvent(event);
		
		if (mRS == null || mScript == null) {
			return false;
		}
		
		float rotation = event.getX() / getWidth() * 360;
		mScript.setRotation(rotation);
		
		return true;
	}

	/**
	 * Verifies that the RenderScriptGL and GraphicsRS classes are instantiated
	 * 
	 * Safe to call multiple times.
	 */
	private void ensureRenderScript() {
		if (mRS == null) {
			RenderScriptGL.SurfaceConfig sc = new RenderScriptGL.SurfaceConfig();
			mRS = createRenderScriptGL(sc);
		}
		if (mScript == null) {
			mScript = new GraphicsRS(mRS, mContext.getResources(), R.raw.graphics);
		}
	}
}
