/*
 * Copyright (C) 2012 Ian G. Clifton
 * Used in The Essentials of Android Application Development LiveLessons
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.iangclifton.android.renderscript;

import android.os.Bundle;
import android.support.v4.app.Fragment;
import android.support.v4.app.FragmentActivity;
import android.support.v4.app.FragmentManager;
import android.support.v4.app.FragmentTransaction;
import android.view.View;

import com.iangclifton.android.R;

/**
 * An Activity for displaying RenderScript results.
 * 
 * @author Ian G. Clifton
 */
public class RenderScriptActivity extends FragmentActivity {
	
	public void onClickComputation(View v) {
		loadFragment(new ComputationFragment());
	}
	
	public void onClickGraphics(View v) {
		loadFragment(new RenderScriptGraphicsFragment());
	}

	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		
		setContentView(R.layout.renderscript);
	}
	
	/**
	 * Adds the specified Fragment to the layout and backstack.
	 * 
	 * @param f Fragment to display
	 */
	private void loadFragment(Fragment f) {
		FragmentManager fm = getSupportFragmentManager();
		FragmentTransaction ft = fm.beginTransaction();
		ft.add(R.id.fragment_container, f);
		ft.addToBackStack(null);
		ft.commit();
	}
}
