/*
 * Copyright (C) 2012 Ian G. Clifton
 * Used in The Essentials of Android Application Development LiveLessons
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.iangclifton.android.services;

import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

import android.app.Service;
import android.content.Intent;
import android.content.SharedPreferences;
import android.os.IBinder;
import android.preference.PreferenceManager;
import android.util.Log;

import com.iangclifton.android.R;
import com.iangclifton.android.webaccess.HttpDownloadTask;

/**
 * Service that loads weather information and sends a broadcast Intent.
 * 
 * @author Ian G. Clifton
 */
public class WeatherService extends Service {
	
	private static final String WEATHER_URL = "http://query.yahooapis.com/v1/public/yql?q=select%%20*%%20from%%20weather.forecast%%20where%%20location%%3D%%22%s%%22&format=json";
	
	private String mHigh;
	private String mLocation;
	
	@Override
	public IBinder onBind(Intent intent) {
		return null;
	}

	@Override
	public int onStartCommand(Intent intent, int flags, int startId) {
		
		new WeatherDownloadTask().execute(getUrl());
		
		return START_NOT_STICKY;
	}
	
	/**
	 * Returns the URL to load for weather as a String
	 * 
	 * @return the URL to load for weather as a String
	 */
	private String getUrl() {
		SharedPreferences prefs = PreferenceManager.getDefaultSharedPreferences(this);
		String city = prefs.getString(getString(R.string.city), getString(R.string.city_default));
		return String.format(WEATHER_URL, city);
	}

	private class WeatherDownloadTask extends HttpDownloadTask {

		@Override
		protected void onPostExecute(String result) {
			try {
				JSONObject json = new JSONObject(result);
				json = json.getJSONObject("query");
				json = json.getJSONObject("results");
				json = json.getJSONObject("channel");
				
				// Get location ("city")
				JSONObject location = json.optJSONObject("location");				
				if (location != null && location.has("city")) {
					mLocation = location.getString("city");
				} else {
					mLocation = getResources().getString(R.string.unknown);
				}
				
				// Get high temperature
				JSONObject item = json.getJSONObject("item");
				JSONArray forecast = item.getJSONArray("forecast");
				JSONObject dayForecast = forecast.getJSONObject(0);
				mHigh = dayForecast.getString("high");
			} catch (JSONException e) {
				// TODO You should handle Exceptions appropriately for your app
				// Even if a given service seems to always give you valid JSON,
				// you should inject JSON that's missing data you need to verify
				// you handle it in a reasonable way.
				e.printStackTrace();
			}
			Log.d("WeatherService", mLocation + ": " + mHigh);
			WeatherUpdate update = new WeatherUpdate(mHigh, mLocation);
			sendBroadcast(update.toIntent());
			stopSelf();
		}
		
	}
}
