/*
 * Copyright (C) 2012 Ian G. Clifton
 * Used in The Essentials of Android Application Development LiveLessons
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.iangclifton.android.services;

import android.content.Intent;
import android.os.Bundle;

/**
 * Represents a WeatherUpdate for easy creation of Intents.
 * 
 * If this is all the class ends up being, then it should really just have a
 * static method to get an Intent for a String high and String location and vice
 * versa; however, in most cases you'll be dealing with a lot more information.
 * This class could then contain that info, methods for saving to/loading from a
 * local database, etc.
 * 
 * @author Ian G. Clifton
 */
public class WeatherUpdate {
	public static final String WEATHER_UPDATE_INTENT = "com.iangclifton.android.WEATHER_UPDATE_INTENT";
	
	private static final String KEY_HIGH = "high";
	private static final String KEY_LOCATION = "location";
	
	private String mHigh;
	private String mLocation;
	
	/**
	 * Constructs a WeatherUpdate from an Intent.
	 * 
	 * @param intent Intent to construct the WeatherUpdate from
	 * @see #toIntent()
	 */
	public WeatherUpdate(Intent intent) {
		Bundle extras = intent.getExtras();
		mHigh = extras.getString(KEY_HIGH);
		mLocation = extras.getString(KEY_LOCATION);
	}
	
	/**
	 * Creates a WeatherUpdate from the passed high and location
	 * 
	 * @param high String representing the high for the weather
	 * @param location String representing the location for the weather
	 */
	public WeatherUpdate(String high, String location) {
		mHigh = high;
		mLocation = location;
	}
	
	/**
	 * Returns the high for this WeatherUpdate
	 * 
	 * @return the high for this WeatherUpdate
	 */
	public String getHigh() {
		return mHigh;
	}
	
	/**
	 * Returns the location for this WeatherUpdate
	 * 
	 * @return the location for this WeatherUpdate
	 */
	public String getLocation() {
		return mLocation;
	}
	
	/**
	 * Returns an Intent containing the weather data from this object
	 * 
	 * @return an Intent containing the weather data from this object
	 */
	public Intent toIntent() {
		Intent i = new Intent();
		i.setAction(WEATHER_UPDATE_INTENT);
		i.putExtra(KEY_HIGH, mHigh);
		i.putExtra(KEY_LOCATION, mLocation);
		
		return i;
	}
}
