/*
 * Modification of 
 * http://code.google.com/p/zippy-android/source/browse/trunk/examples/SharedPreferencesCompat.java
 * 
 * Original content Copyright (C) 2010 The Android Open Source Project
 * Updated content Copyright (C) 2012 Ian G. Clifton
 * Used in The Essentials of Android Application Development LiveLessons
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.iangclifton.android.utils;

import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;

import android.content.SharedPreferences;

public class SharedPreferencesCompat {
	private static final Method sApplyMethod = findApplyMethod();
	
	public static void apply(SharedPreferences.Editor editor) {
		if (sApplyMethod != null) {
			try {
				sApplyMethod.invoke(editor);
				return;
			} catch (IllegalArgumentException e) {
			} catch (IllegalAccessException e) {
			} catch (InvocationTargetException e) {
			}
		}
		editor.commit();
	}

	private static Method findApplyMethod() {
		try {
			return SharedPreferences.Editor.class.getMethod("apply");
		} catch (NoSuchMethodException e) {
			// Method unavailable
		}
		return null;
	}
}
