/*
 * Copyright (C) 2012 Ian G. Clifton
 * Used in The Essentials of Android Application Development LiveLessons
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.iangclifton.android.view;

import android.content.Context;
import android.graphics.Bitmap;
import android.graphics.drawable.Drawable;
import android.util.AttributeSet;
import android.view.LayoutInflater;
import android.widget.ImageView;
import android.widget.RelativeLayout;
import android.widget.TextView;

import com.iangclifton.android.R;

/**
 * Our poorly named custom RelativeLayout.
 * 
 * This View automatically inflates a layout and provides easier methods for
 * setting the contents of those Views.  AuthorBox replaces this View.
 * 
 * @author Ian G. Clifton
 * @see AuthorBox
 */
public class CustomLayout extends RelativeLayout {
	
	private ImageView mThumbnail;
	private TextView mMainText;
	private TextView mSubText;

	public CustomLayout(Context context) {
		super(context);
		init(context);
	}

	public CustomLayout(Context context, AttributeSet attrs) {
		super(context, attrs);
		init(context);
	}

	public CustomLayout(Context context, AttributeSet attrs, int defStyle) {
		super(context, attrs, defStyle);
		init(context);
	}
	
	public CustomLayout(Context context, int thumbnailResourceId, String mainText, String subText) {
		super(context);
		init(context);
		mThumbnail.setImageResource(thumbnailResourceId);
		mMainText.setText(mainText);
		mSubText.setText(subText);
	}
	
	public void setMainText(String mainText) {
		mMainText.setText(mainText);
	}
	
	public void setSubText(String subText) {
		mSubText.setText(subText);
	}
	
	public void setThumbnail(Bitmap bitmap) {
		mThumbnail.setImageBitmap(bitmap);
	}
	
	public void setThumbnail(Drawable drawable) {
		mThumbnail.setImageDrawable(drawable);
	}
	
	public void setThumbnail(int resourceId) {
		mThumbnail.setImageResource(resourceId);
	}
	
	private void init(Context context) {
		LayoutInflater inflater = LayoutInflater.from(context);
		inflater.inflate(R.layout.author_box, this);
		mThumbnail = (ImageView) findViewById(R.id.thumbnail);
		mMainText = (TextView) findViewById(R.id.main_text);
		mSubText = (TextView) findViewById(R.id.sub_text);
	}
}
