/*
 * Copyright (C) 2012 Ian G. Clifton
 * Used in The Essentials of Android Application Development LiveLessons
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.iangclifton.android.webaccess;

import java.io.IOException;
import java.net.HttpURLConnection;
import java.security.InvalidParameterException;

import org.apache.http.HttpEntity;
import org.apache.http.HttpResponse;
import org.apache.http.client.ClientProtocolException;
import org.apache.http.client.HttpClient;
import org.apache.http.client.methods.HttpGet;
import org.apache.http.impl.client.DefaultHttpClient;
import org.apache.http.util.EntityUtils;

import android.os.AsyncTask;
import android.text.TextUtils;

/**
 * Simple AsyncTask for downloading web content.
 * 
 * In a real app, you would want to be robust in error handling and the ability
 * to request different types of data.
 * 
 * @author Ian G. Clifton
 */
public class HttpDownloadTask extends AsyncTask<String, Void, String> {

	@Override
	protected String doInBackground(String... urls) {
		if (urls.length != 1) {
			throw new InvalidParameterException("urls must be a length of 1; it was " + urls.length);
		}
		if (TextUtils.isEmpty(urls[0])) {
			throw new InvalidParameterException("urls must not be null or an empty string");
		}
		
		// AndroidHttpClient can be used for better defaults as of API level 8
		HttpClient client = new DefaultHttpClient();
		HttpGet httpGet = new HttpGet(urls[0]);
		try {
			HttpResponse response = client.execute(httpGet);
			if (response.getStatusLine().getStatusCode() == HttpURLConnection.HTTP_OK) {
				HttpEntity entity = response.getEntity();
				String result = EntityUtils.toString(entity);
				return result;
			}
		} catch (ClientProtocolException e) {
			e.printStackTrace();
		} catch (IOException e) {
			e.printStackTrace();
		}
		return null;
	}

}
