/*
 * Copyright (C) 2012 Ian G. Clifton
 * Used in The Essentials of Android Application Development LiveLessons
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.iangclifton.android.widgets;

import android.app.PendingIntent;
import android.appwidget.AppWidgetManager;
import android.appwidget.AppWidgetProvider;
import android.content.ComponentName;
import android.content.Context;
import android.content.Intent;
import android.content.SharedPreferences;
import android.preference.PreferenceManager;
import android.widget.RemoteViews;

import com.iangclifton.android.MainActivity;
import com.iangclifton.android.R;
import com.iangclifton.android.services.WeatherService;
import com.iangclifton.android.services.WeatherUpdate;

/**
 * An AppWidgetProvider that uses a Service to get weather info.
 * 
 * @author Ian G. Clifton
 */
public class WeatherWidget extends AppWidgetProvider {

	@Override
	public void onReceive(Context context, Intent intent) {
		
		// Receiving data from a custom Service is extremely common in widgets
		if (intent.getAction().equals(WeatherUpdate.WEATHER_UPDATE_INTENT)) {
			WeatherUpdate update = new WeatherUpdate(intent);
			String viewText;
			SharedPreferences prefs = PreferenceManager.getDefaultSharedPreferences(context);
			String key = context.getString(R.string.show_city);
			if (prefs.getBoolean(key, true)) {
				viewText = update.getLocation() + ": " + update.getHigh();
			} else {
				viewText = update.getHigh();
			}
			RemoteViews views = getRemoteViews(context, viewText);
			
			AppWidgetManager appWidgetManager = AppWidgetManager.getInstance(context);
			ComponentName componentName = new ComponentName(context, WeatherWidget.class);
			appWidgetManager.updateAppWidget(componentName, views);
		} else {
			super.onReceive(context, intent);			
		}
	}

	@Override
	public void onUpdate(Context context, AppWidgetManager appWidgetManager,
			int[] appWidgetIds) {
		
		RemoteViews views = getRemoteViews(context, "Updating...");
		appWidgetManager.updateAppWidget(appWidgetIds, views);
		
		Intent serviceIntent = new Intent(context, WeatherService.class);
		context.startService(serviceIntent);
	}

	/**
	 * Helper method to easily get the RemoteViews with onClick already set
	 * 
	 * @param context Context for the Intent
	 * @param textViewContent String to display in the TextView
	 * @return RemoteViews created and updated in this call
	 */
	private RemoteViews getRemoteViews(Context context, String textViewContent) {
		RemoteViews views = new RemoteViews(context.getPackageName(), R.layout.weather_widget);
		views.setTextViewText(R.id.weather, textViewContent);

		Intent intent = new Intent(context, MainActivity.class);
		PendingIntent pendingIntent = PendingIntent.getActivity(context, 0, intent, 0);
		views.setOnClickPendingIntent(R.id.weather_widget_root, pendingIntent);
		
		return views;
	}
}
